/*--------------------------------------------------------------------*/
/*  This file contains sample code.  IBM PROVIDES THIS CODE ON AN     */
/*  'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS        */
/*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  */
/*  OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.          */
/*                                                                    */
/*  (C) Copyright IBM Corp. 1998, 2000                                */
/*--------------------------------------------------------------------*/
package com.ibm.etill.kitcashcassette;

import java.sql.*;
import java.util.*;

import com.ibm.etill.framework.cassette.query.*;
import com.ibm.etill.framework.log.*;
import com.ibm.etill.framework.payapi.*;
import com.ibm.etill.framework.xdm.*;

/**
 * This class is instantiated by the <code>KitCashCassetteQuery.query</code>
 * method when it receives an AccountQueryRequest from the Payment Servlet.
 * This class handles the query.
 */
public class KitCashAccountQueryRequest extends QueryRequest implements KitCashAccountConstants {
   private Vector accounts = null;

   /**
    * Construct a KitCashAccountQueryRequest object.  The object simply invokes
    * its superclass' constructor and then starts the query.
    * @param accountRequest the query request
    * @param accounts the framework accounts resulting from the query
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the construction fails.
    */
   public KitCashAccountQueryRequest (AccountQueryRequest accountRequest, Enumeration accounts) throws ETillAbortOperation {
      super(accountRequest);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.KitCashAccountQueryRequest");
      query();
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.KitCashAccountQueryRequest");
   }
   
   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String fromClause() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.fromClause");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.fromClause");
      return tableName();
   }

   /**
    * Returns the list of accounts found by this query.
    *
    * @return the list of accounts
    */
   protected Vector getAccounts() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.getAccounts");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.getAccounts");
      return accounts;
   }

   /**
    * Allows this object to process the results of its query into a list of account
    * objects.
    *
    * @return the size of the list
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the query fails.
    */
   protected int processQueryResults(ResultSet resultSet) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.processQueryResults");
      accounts = PSServerKitCashAccount.query(resultSet);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.processQueryResults");
      return accounts.size();
   }

   /**
    * Returns the selection criteria to be used in the "SELECT" clause of the query being executed.
    *
    * @return the selection statement
    */
   protected String selectStatement() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.selectStatement");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.selectStatement");
      return "*";
   }

   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String tableName() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.tableName");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.tableName");
      return KitCashAccountConstants.KITCASHACCOUNTS_VIEW;
   }
   
   /**
    * Returns the where condition to be used in the "WHERE" clause of the query being executed.
    *
    * @return the where condition
    */
   public String whereCondition() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.whereCondition");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashAccountQueryRequest.whereCondition");
      return getOriginalRequest().whereCondition();
   }
}
