/*--------------------------------------------------------------------*/
/*  This file contains sample code.  IBM PROVIDES THIS CODE ON AN     */
/*  'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS        */
/*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  */
/*  OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.          */
/*                                                                    */
/*  (C) Copyright IBM Corp. 1998, 2000                                */
/*--------------------------------------------------------------------*/
package com.ibm.etill.kitcashcassette;

import java.sql.*;
import java.util.*;

import com.ibm.etill.framework.cassette.query.*;
import com.ibm.etill.framework.log.*;
import com.ibm.etill.framework.payapi.*;
import com.ibm.etill.framework.xdm.*;

/**
 * This class is instantiated by the <code>KitCashCassetteQuery.query</code>
 * method when it receives a CassetteQueryRequest from the Payment Servlet.
 * This class handles the query.
 */
public class KitCashCassetteAdminQueryRequest extends QueryRequest implements KitCashCassetteAdminConstants {
   private PSServerKitCashCassetteAdmin cassette = null;

   /**
    * Construct a KitCashCassetteAdminQueryRequest object.  The object simply invokes
    * its superclass' constructor and then starts the query.
    * @param cassetteRequest the query request
    * @param cassettes the framework cassettes resulting from the query
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the construction fails.
    */
   public KitCashCassetteAdminQueryRequest (CassetteQueryRequest cassetteRequest, Enumeration cassettes) throws ETillAbortOperation {
      super(cassetteRequest);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.KitCashCassetteAdminQueryRequest");
      query();
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.KitCashCassetteAdminQueryRequest");
   }

   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String fromClause() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.fromClause");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.fromClause");
      return tableName();
   }

   /**
    * Returns the cassette admin object found by this query.
    *
    * @return the cassette admin
    */
   public PSServerKitCashCassetteAdmin getKitCashCassette() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.getKitCashCassette");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.getKitCashCassette");
      return cassette;
   }

   /**
    * Allows this object to process the results of its query into a cassette admin object.
    *
    * @return the size of the list (1)
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the query fails.
    */
   protected int processQueryResults(ResultSet resultSet) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.processQueryResults");
      cassette = PSServerKitCashCassetteAdmin.query(resultSet);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.processQueryResults");
      return 1;
   }

   /**
    * Returns the selection criteria to be used in the "SELECT" clause of the query being executed.
    *
    * @return the selection statement
    */
   protected String selectStatement() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.selectStatement");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.selectStatement");
      return "*";
   }

   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String tableName() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.tableName");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.tableName");
      return KitCashCassetteAdminConstants.KITCASHCASSETTE_TABLE;
   }
   
   /**
    * Returns the where condition to be used in the "WHERE" clause of the query being executed.
    *
    * @return the where condition
    */
   public String whereCondition() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.whereCondition");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteAdminQueryRequest.whereCondition");
      return null;
   }
}
