/*--------------------------------------------------------------------*/
/*  This file contains sample code.  IBM PROVIDES THIS CODE ON AN     */
/*  'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS        */
/*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  */
/*  OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.          */
/*                                                                    */
/*  (C) Copyright IBM Corp. 1998, 2000                                */
/*--------------------------------------------------------------------*/
package com.ibm.etill.kitcashcassette;

import java.util.*;

import com.ibm.etill.framework.cassette.query.*;
import com.ibm.etill.framework.log.*;
import com.ibm.etill.framework.payapi.*;
import com.ibm.etill.framework.payserverapi.PaymentServletConstants;
import com.ibm.etill.framework.xdm.*;

/**
 * This class is instantiated by the Payment Manager framework to respond to queries
 * from the Payment Servlet about the KitCash cassette.  It is the counterpart of KitCashCassette
 * that runs under the servlet.
 */
public final class KitCashCassetteQuery extends CassetteQuery {

   /**
    * Construct a KitCashCassetteQuery object.
    * Called by the Payment Servlet once for this cassette.
    */
   public KitCashCassetteQuery() {
      super(KitCashCassette.TRACEID);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteQuery.KitCashCassetteQuery");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteQuery.KitCashCassetteQuery");
   }

   /**
    * Processes query requests from the framework.
    * @param queryRequest the request
    * @param objects the list of objects to process
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the query fails
    * @exception com.ibm.etill.framework.log.ETillCassetteException
    *            if the cassette receives a query it does not recognize
    *
    */
   public void query(QueryRequest queryRequest, Vector objects) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashCassetteQuery.query");

      if (queryRequest instanceof OrderQueryRequest) {
         KitCashPurchaseQueryRequest purchaseRequest = new KitCashPurchaseQueryRequest((OrderQueryRequest) queryRequest,objects.elements());
         Vector purchases = purchaseRequest.getPurchases();
         PSServerKitCashPurchase.combineQueryResults(purchases.elements(),objects.elements());
      } else if (queryRequest instanceof CassetteQueryRequest) {
         KitCashCassetteAdminQueryRequest cassetteRequest = new KitCashCassetteAdminQueryRequest((CassetteQueryRequest) queryRequest,objects.elements());
         PSServerKitCashCassetteAdmin kitCashCassette = cassetteRequest.getKitCashCassette();
         PSServerCassette cassette = (objects != null && objects.size() == 1 ? (PSServerCassette) objects.firstElement() : null);
         PSServerKitCashCassetteAdmin.combineQueryResults(kitCashCassette,cassette);
      } else if (queryRequest instanceof AccountQueryRequest) {
         KitCashAccountQueryRequest accountRequest = new KitCashAccountQueryRequest((AccountQueryRequest) queryRequest,objects.elements());
         Vector accounts = accountRequest.getAccounts();
         PSServerKitCashAccount.combineQueryResults(accounts.elements(),objects.elements());
      } else if (queryRequest instanceof PaymentQueryRequest) {
         /* the KitCashCassette does not include a cassette-specific Payment object */
      } else if (queryRequest instanceof CreditQueryRequest) {
         /* the KitCashCassette does not include a cassette-specific Credit object */
      } else if (queryRequest instanceof BatchQueryRequest) {
         /* the KitCashCassette does not include a cassette-specific Batch object */
      } else if (queryRequest instanceof PaymentSystemQueryRequest) {
         /* the KitCashCassette does not include a cassette-specific PaymentSystem object */
      } else {
         /* the KitCashCassette ignores other types of query requests */
      }

      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashCassetteQuery.query");
   }
}
