/***********************************************************************************
 // This file is 100% machine generated.  ** Do Not Edit! 
 ***********************************************************************************/

package com.ibm.etill.kitcashcassette;

import com.ibm.etill.framework.supervisor.FSM;
import com.ibm.etill.framework.payapi.ETillAbortOperation;
import com.ibm.etill.framework.payapi.PaymentAPIConstants;
import com.ibm.etill.kitcashcassette.test.card.KitCashConstants;

/***********************************************************************************
    This derived FSM class defines the state machine logic
    as represented in the FSM project (.prj) file.
    The project file is created by FSMEdit.
    FSMEdit can be used to generate an html representation
    of this state machine matrix from the project file.

    This class extends the Framework's FSM class.
    When the base class method processEvent() is called,
    the following logic is invoked:
            row = determineInputRow(input)
            state = currentState
            currentState = (matrix [row] [state]).getNextState
            action = (matrix [row] [state]).getAction
            And last, the FSMUser class' action method is called.
 ***********************************************************************************/
public class KitCashFSM extends FSM implements KitCashFSMConstants
{

  private KitCashFSMUser theUser;
  
  public KitCashFSM (KitCashFSMUser fsmUser, int state)
  {
    myState.setState(state);
    theUser = fsmUser;
  }
  
  protected int determineInputRow (int input)
  {
    int rowNumber = INVALID_INPUT;
    switch (input)
    {
      //---------------------------------------------------------------
      // ReceivePayment
      // ReceivePayment is the input sent to the finite state machine when the Merchant sends a RECEIVEPAYMENT API request to the Payment Server.
      //---------------------------------------------------------------
      case ReceivePayment:
      {
        rowNumber = 0;
      }
      break;
      //---------------------------------------------------------------
      // KitCashMsg
      // KitCashMsg is the input sent to the finite state machine when a protocol message arrives from the KitCash wallet.
      //---------------------------------------------------------------
      case KitCashMsg:
      {
        rowNumber = 1;
      }
      break;
      //---------------------------------------------------------------
      // EndOfConsumerFlow
      // EndOfConsumerFlow is the input sent to the finite state machine when the merchant's KitCash card drvier signifies that the KitCash protocol flow has ended.
      //---------------------------------------------------------------
      case EndOfConsumerFlow:
      {
        rowNumber = 2;
      }
      break;
      //---------------------------------------------------------------
      // Deposit
      // The Deposit input is sent to the finite state machine when the KitCash protocol flow has concluded successfully.
      //---------------------------------------------------------------
      case Deposit:
      {
        rowNumber = 3;
      }
      break;
      //---------------------------------------------------------------
      // BatchClosed
      // BatchClosed is sent to the finite state machine when the account and the batch have been closed (and the payment has been sent to the KitCash bank).
      //---------------------------------------------------------------
      case BatchClosed:
      {
        rowNumber = 4;
      }
      break;
      //---------------------------------------------------------------
      // Error
      // Error is the input sent to the finite state machine when the merchant's KitCash card driver signifies that the KitCash protocol flow ended in error.
      //---------------------------------------------------------------
      case Error:
      {
        rowNumber = 5;
      }
      break;
      //---------------------------------------------------------------
      // OrderClosed
      // Close order is sent to the finite state machine when the batch has been settled (closed) to delete the order from the database.
      //---------------------------------------------------------------
      case OrderClosed:
      {
        rowNumber = 6;
      }
      break;
    }
    return rowNumber;
  }


  protected Integer performAction (int row, int state) throws ETillAbortOperation
  {
    Integer result = null;
    switch (fsmMatrix [row][stateTable[state]][0])
    {
      //---------------------------------------------------------------
      // SendInitiationMsg
      // Sends the KitCash wallet applet tag back to the merchant. 
      //---------------------------------------------------------------
      case SendInitiationMsg:
      {
        result = theUser.sendInitiationMsg();
      }
      break;
      //---------------------------------------------------------------
      // StartPayment
      // Receives a KitCash protocol message from the consumer and returns a response KitCash protocol message. Records on the database that the order and payment are pending.
      //---------------------------------------------------------------
      case StartPayment:
      {
        result = theUser.startPayment();
      }
      break;
      //---------------------------------------------------------------
      // ContinuePayment
      // Receives a KitCash protocol message from the wallet and returns a response KitCash protocol message. Queries the merchant's KitCash card driver to determine whether the payment has concluded or not. Records the current state on the database.
      //---------------------------------------------------------------
      case ContinuePayment:
      {
        result = theUser.continuePayment();
      }
      break;
      //---------------------------------------------------------------
      // MarkPaymentForDeposit
      // Records on the database that the purchase object has been added to a batch of payments to be transferred to the bank.
      //---------------------------------------------------------------
      case MarkPaymentForDeposit:
      {
        result = theUser.markPaymentForDeposit();
      }
      break;
      //---------------------------------------------------------------
      // MarkPaymentAsComplete
      // Records on the database that the payment associated with this purchase has been successfully transferred\ to the bank.
      //---------------------------------------------------------------
      case MarkPaymentAsComplete:
      {
        result = theUser.markPaymentAsComplete();
      }
      break;
      //---------------------------------------------------------------
      // MarkPaymentAsReceived
      // Records on the database that the KitCash protocol flow has completed successfully and that the consumer's money has been transffered to the merchant's KitCash card.
      //---------------------------------------------------------------
      case MarkPaymentAsReceived:
      {
        result = theUser.markPaymentAsReceived();
      }
      break;
      //---------------------------------------------------------------
      // ReportError
      // Reports that an error has occurred during processing.
      //---------------------------------------------------------------
      case ReportError:
      {
        result = theUser.reportError();
      }
      break;
      //---------------------------------------------------------------
      // CloseOrder
      // Closes a settled order.
      //---------------------------------------------------------------
      case CloseOrder:
      {
        result = theUser.closeOrder();
      }
      break;
    }
    return result;
  }
  
  protected int getNextState (int row, int state)
  {
    int matrixState;
    int nextState;
    
    matrixState = stateTable [state];
    nextState = fsmMatrix [row] [matrixState] [1];
    if (nextState == NO_STATE_CHANGE)
      nextState = state;
    return nextState;
  }
  
  protected int getAction (int row, int state)
  {
    int matrixState;
    
    matrixState = stateTable [state];
    return fsmMatrix [row] [matrixState] [0];
  }
  
  public boolean validState (int input)
  {
    int row = determineInputRow (input);
    return (getAction (row, myState.getState()) != UNREACHABLE_STATE_ACTION);
  }
  
  private static int [] stateTable =
    {0, 1, 2, 3, 4, 5, 6};
  
  private static int [][][] fsmMatrix =
  {
    //---------------------------------------------------------------
    // Input:ReceivePayment
    //---------------------------------------------------------------
    {
      {SendInitiationMsg, PaymentRequested},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    },
    //---------------------------------------------------------------
    // Input:KitCashMsg
    //---------------------------------------------------------------
    {
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {StartPayment, PaymentPending},
      {ContinuePayment, PaymentPending},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    },
    //---------------------------------------------------------------
    // Input:EndOfConsumerFlow
    //---------------------------------------------------------------
    {
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {MarkPaymentAsReceived, PaymentReceived},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    },
    //---------------------------------------------------------------
    // Input:Deposit
    //---------------------------------------------------------------
    {
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {MarkPaymentForDeposit, PaymentAddedToBatch},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    },
    //---------------------------------------------------------------
    // Input:BatchClosed
    //---------------------------------------------------------------
    {
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {MarkPaymentAsComplete, PaymentComplete},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    },
    //---------------------------------------------------------------
    // Input:Error
    //---------------------------------------------------------------
    {
      {ReportError, ErrorState},
      {ReportError, ErrorState},
      {ReportError, ErrorState},
      {ReportError, ErrorState},
      {ReportError, ErrorState},
      {ReportError, ErrorState},
      {ReportError, ErrorState}
    },
    //---------------------------------------------------------------
    // Input:OrderClosed
    //---------------------------------------------------------------
    {
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {UNREACHABLE_STATE_ACTION, NO_STATE_CHANGE},
      {CloseOrder, PaymentComplete},
      {UNREACHABLE_STATE_ACTION,NO_STATE_CHANGE}
    }
  };
}
