/*--------------------------------------------------------------------*/
/*  This file contains sample code.  IBM PROVIDES THIS CODE ON AN     */
/*  'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS        */
/*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  */
/*  OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.          */
/*                                                                    */
/*  (C) Copyright IBM Corp. 1998, 2000                                */
/*--------------------------------------------------------------------*/
package com.ibm.etill.kitcashcassette;

import java.sql.*;
import java.util.*;

import com.ibm.etill.framework.cassette.query.*;
import com.ibm.etill.framework.log.*;
import com.ibm.etill.framework.payapi.*;
import com.ibm.etill.framework.xdm.*;

/**
 * This class is instantiated by the <code>KitCashCassetteQuery.query</code>
 * method when it receives an OrderQueryRequest from the Payment Servlet.
 * This class handles the query.
 */
public class KitCashPurchaseQueryRequest extends QueryRequest implements KitCashPurchaseConstants {
   private Vector purchases = null;

   /**
    * Construct a KitCashPurchaseQueryRequest object.  The object simply invokes
    * its superclass' constructor and then starts the query.
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the construction fails.
    */
   public KitCashPurchaseQueryRequest (OrderQueryRequest orderRequest, Enumeration orders) throws ETillAbortOperation {
      super(orderRequest);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.KitCashPurchaseQueryRequest");
      query();
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.KitCashPurchaseQueryRequest");
   }

   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String fromClause() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.fromClause");
      QueryRequest originalRequest = getOriginalRequest();
      if (originalRequest == this || originalRequest instanceof OrderQueryRequest || originalRequest instanceof PaymentQueryRequest) {
         if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.fromClause");
         return tableName();
      } else {
         if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.fromClause");
         throw new ETillCassetteException();
      }
   }

   /**
    * Returns the list of purchases (orders) found by this query.
    *
    * @return the list of purchases
    */
   protected Vector getPurchases() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.getPurchases");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.getPurchases");
      return purchases;
   }

   /**
    * Allows this object to process the results of its query into a list of purchase
    * objects.
    *
    * @return the size of the list
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the query fails.
    */
   protected int processQueryResults(ResultSet resultSet) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.processQueryResults");
      purchases = PSServerKitCashPurchase.query(resultSet);
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.processQueryResults");
      return purchases.size();
   }

   /**
    * Returns the selection criteria to be used in the "SELECT" clause of the query being executed.
    *
    * @return the selection statement
    */
   protected String selectStatement() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.selectStatement");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.selectStatement");
      return "*";
   }

   /**
    * Returns the table name to be used in the "FROM" clause of the query being executed.
    *
    * @return the table name
    */
   protected String tableName() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.tableName");
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.tableName");
      return KitCashPurchaseConstants.KITCASHPURCH_VIEW;
   }

   /**
    * Returns the where condition to be used in the "WHERE" clause of the query being executed.
    *
    * @return the where condition
    */
   public String whereCondition() {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.whereCondition");
      QueryRequest originalRequest = getOriginalRequest();
      if (originalRequest == this || originalRequest instanceof OrderQueryRequest) {
         if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.whereCondition");
         return originalRequest.whereCondition();
      } else if (originalRequest instanceof PaymentQueryRequest || originalRequest instanceof CreditQueryRequest) {
         if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.whereCondition");
         return null;
      } else {
         if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID, "KitCashPurchaseQueryRequest.whereCondition");
         throw new ETillCassetteException();
      }
   }
}
