/*--------------------------------------------------------------------*/
/*  This file contains sample code.  IBM PROVIDES THIS CODE ON AN     */
/*  'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS        */
/*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES  */
/*  OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.          */
/*                                                                    */
/*  (C) Copyright IBM Corp. 1998, 2000                                */
/*--------------------------------------------------------------------*/
package com.ibm.etill.kitcashcassette;

import java.sql.*;
import java.util.*;

import com.ibm.etill.framework.archive.*;
import com.ibm.etill.framework.cassette.query.*;
import com.ibm.etill.framework.ETill;
import com.ibm.etill.framework.log.*;
import com.ibm.etill.framework.payserverapi.*;
import com.ibm.etill.framework.payapi.*;
import com.ibm.etill.framework.xdm.*;

/**
 * This class is used by the <code>KitCashCassetteAdminQueryRequest</code>
 * class to create KitCash specific objects as a result of a query request, and to combine those
 * objects with the framework ones supplied with the request.
 */
final public class PSServerKitCashCassetteAdmin implements KitCashCassetteAdminConstants, PaymentAPIConstants {
   private int protocolPort;

   /**
    * Constructs a PSServerKitCashCassetteAdmin object using the result set produced
    * from the query.
    * @param rs the ResultSet produced from the query
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the construction fails.
    */
   private PSServerKitCashCassetteAdmin(ResultSet rs) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.PSServerKitCashCassetteAdmin");
      try {
         protocolPort = ETillArchive.readInteger(rs,COL_PROTOCOLPORT).intValue();
      } catch (SQLException e) {
         if (Trace.isAnyoneTracing()) Trace.traceDebug(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin(ResultSet): " + e);
         ErrorLog.logError(ETill.RB_ID, "0205", e, e.toString());
         throw new ETillAbortOperation(PRC_DATABASE_ERROR,RC_ERROR_CONNECTING_DATABASE_OR_EXEC_SQL);
      }
      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.PSServerKitCashCassetteAdmin");
   }

   /**
    * Combines a PSServerKitCashCassetteAdmin object with a framework cassette object.
    * @param kitCashCassette the PSServerKitCashCassetteAdmin object
    * @param cassette the PSServerCassette object
    */
   public static void combineQueryResults(PSServerKitCashCassetteAdmin kitCashCassette, PSServerCassette cassette) {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.combineQueryResults");

      CassetteExtensionObject object = new CassetteExtensionObject();

      object.addProperty(XDM_PROTOCOLPORT, new Integer(kitCashCassette.protocolPort), null);

      cassette.setCassetteExtensionObject(object);

      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.combineQueryResults");
   }

   /**
    * Creates PSServerKitCashCassetteAdmin objects from each item in the result set.
    * @param rs the the ResultSet
    * @exception com.ibm.etill.framework.payapi.ETillAbortOperation
    *            if the query fails.
    */
   public static PSServerKitCashCassetteAdmin query(ResultSet rs) throws ETillAbortOperation {
      if (Trace.isAnyoneTracing()) Trace.traceFunctionEntry(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.query");
      Vector result = new Vector();

      try {
         while (rs.next()) {
            PSServerKitCashCassetteAdmin newCassette = new PSServerKitCashCassetteAdmin(rs);
            result.addElement(newCassette);
         }
      } catch (SQLException e) {
         ErrorLog.logError(ETill.RB_ID, "0205", e, e.toString());
         throw new ETillAbortOperation(PRC_DATABASE_ERROR,RC_ERROR_CONNECTING_DATABASE_OR_EXEC_SQL);
      }

      if (result.size() != 1) {
         throw new ETillCassetteException();
      }

      if (Trace.isAnyoneTracing()) Trace.traceFunctionExit(KitCashCassette.TRACEID,"PSServerKitCashCassetteAdmin.query");
      return (PSServerKitCashCassetteAdmin) result.firstElement();
   }
}
